import React, { useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { loginUser, captchaCheck } from '../../comunication/FetchUser';
import ReCAPTCHA from 'react-google-recaptcha';

/**
 * LoginUser
 * @author Peter Rutschmann
 */
function LoginUser({ loginValues, setLoginValues }) {
    const navigate = useNavigate();
    const [recaptchaToken, setRecaptchaToken] = useState(null);

    const handleCaptcha = (token) => {
        setRecaptchaToken(token);
    };

    const handleSubmit = async (e) => {
        e.preventDefault();

        if (!recaptchaToken) {
            alert("Please verify reCAPTCHA");
            return;
        }

        try {
            const captchaData = await captchaCheck(recaptchaToken);

            let isLoginValid = false
            isLoginValid = await loginUser(loginValues);
            if (isLoginValid || captchaData.success) {
                setLoginValues({ userName: loginValues.email, password: loginValues.password });
                navigate('/');
            }
        } catch (error) {
            console.error('Failed to fetch to server:', error.message);
        }
    };

    return (
        <div>
            <h2>Login user</h2>
            <form onSubmit={handleSubmit}>
                <section>
                    <aside>
                        <div>
                            <label>Email:</label>
                            <input
                                type="email"
                                value={loginValues.email}
                                onChange={(e) =>
                                    setLoginValues(prevValues => ({ ...prevValues, email: e.target.value }))}
                                required
                                placeholder="Please enter your email *"
                            />
                        </div>
                        <div>
                            <label>Password:</label>
                            <input
                                type="password"
                                value={loginValues.password}
                                onChange={(e) =>
                                    setLoginValues(prevValues => ({ ...prevValues, password: e.target.value }))}
                                required
                                placeholder="Please enter your password *"
                            />
                        </div>
                    </aside>
                </section>
                <ReCAPTCHA
                    sitekey="6LdJj1crAAAAABcEz65x0DUAsuJUBCKwdSi1Mewj"
                    onChange={handleCaptcha}
                />
                <button type="submit">Login</button>
            </form>
        </div>
    );
}

export default LoginUser;
